@@ -1,5 +1,5 @@
 from argparse import ArgumentParser
-from dgx import create_app, delete_app
+from .dgx import create_app, delete_app, add_optional, create_module
 
 parser = ArgumentParser(description='Dealergeek Generator API Express', usage='DGX', )
 
@@ -8,14 +8,28 @@ parser.add_argument(
     "--delete",
     default=None,
     required=False,
-    help="Delete the project",
+    help="Delete the project"
+)
+parser.add_argument(
+    "-i",
+    "--init",
+    default=None,
+    required=False,
+    help="Create a new api"
+)
+parser.add_argument(
+    "-a",
+    "--add",
+    default=None,
+    required=False,
+    help="Add a module"
 )
 parser.add_argument(
     "-c",
     "--create",
     default=None,
     required=False,
-    help="Create a new api",
+    help="Create a new module"
 )
 
 
@@ -24,10 +38,14 @@ def main():
     Evalua los parametros
     """
     args = parser.parse_args()
-    if args.create:
-        create_app(args.create)
+    if args.init:
+        create_app(args.init)
     elif args.delete:
         delete_app(args.delete)
+    elif args.add:
+        add_optional(args.add, None)
+    elif args.create:
+        create_module(args.create)
     else:
         parser.print_help()
 
